@@ -9,19 +9,19 @@ import os
 
 def test_prepare_renderer():
     configurator = Configurator(
-        template='bobtemplates.plone:vocabulary',
-        target_directory='.',
+        template="bobtemplates.plone:vocabulary",
+        target_directory=".",
         variables={
-            'vocabulary_name': 'ExampleVocabulary',
+            "vocabulary_name": "ExampleVocabulary",
         },
     )
     vocabulary.prepare_renderer(configurator)
 
 
 def test_post_renderer(tmpdir):
-    target_path = tmpdir.strpath + '/collective.todo'
-    package_path = target_path + '/src/collective/todo'
-    profiles_path = package_path + '/profiles/default'
+    target_path = tmpdir.strpath + "/collective.todo"
+    package_path = target_path + "/src/collective/todo"
+    profiles_path = package_path + "/profiles/default"
     os.makedirs(target_path)
     os.makedirs(package_path)
     os.makedirs(profiles_path)
@@ -34,21 +34,21 @@ def test_post_renderer(tmpdir):
   </dependencies>
 </metadata>
 """
-    with open(os.path.join(profiles_path + '/metadata.xml'), 'w') as f:
+    with open(os.path.join(profiles_path + "/metadata.xml"), "w") as f:
         f.write(template)
 
     template = """
 [main]
 version=5.1
 """
-    with open(os.path.join(target_path + '/bobtemplate.cfg'), 'w') as f:
+    with open(os.path.join(target_path + "/bobtemplate.cfg"), "w") as f:
         f.write(template)
 
     template = """
     dummy
     '-*- Extra requirements: -*-'
 """
-    with open(os.path.join(target_path + '/setup.py'), 'w') as f:
+    with open(os.path.join(target_path + "/setup.py"), "w") as f:
         f.write(template)
 
     template = """
@@ -62,18 +62,18 @@ version=5.1
 
     </configure>
 """
-    with open(os.path.join(package_path + '/configure.zcml'), 'w') as f:
+    with open(os.path.join(package_path + "/configure.zcml"), "w") as f:
         f.write(template)
     configurator = Configurator(
-        template='bobtemplates.plone:vocabulary',
+        template="bobtemplates.plone:vocabulary",
         target_directory=package_path,
         bobconfig={
-            'non_interactive': True,
+            "non_interactive": True,
         },
         variables={
-            'plone.version': '5.1',
-            'vocabulary_name': 'AvailableTasks',
-            'vocabulary_description': 'Bla',
+            "plone.version": "5.1",
+            "vocabulary_name": "AvailableTasks",
+            "vocabulary_description": "Bla",
         },
     )
 
